==> dearpygui_ext-0.8.0.tar.gz: dearpygui_ext-0.8.0/README.md <==
<a id="user-content-dear-pygui" class="anchor" aria-hidden="true" href="#dear-pygui">
 
<div align="center">
  <img src="https://github.com/hoffstadt/DearPyGui/blob/assets/newlogo.jpg?raw=true" alt="Dear PyGui">
</div>

</a>

<h6 align="center">(This library is available under a free and permissive license however, if you Enjoy <i>Dear PyGui</i> please consider becoming a <a href="https://github.com/hoffstadt/DearPyGui/wiki/Sponsors">Sponsor</a>)</h6>

![Python Version](https://img.shields.io/pypi/pyversions/dearpygui-ext)
[![PYPI](https://img.shields.io/pypi/v/dearpygui-ext)](https://pypi.org/project/dearpygui-ext/)
[![Deploy Package](https://github.com/hoffstadt/DearPyGui_Ext/actions/workflows/DeployPackage.yml/badge.svg)](https://github.com/hoffstadt/DearPyGui_Ext/actions/workflows/DeployPackage.yml)

**Dear PyGui Extensions** is a collection of useful tools, abstractions, and simplification layers built with/for _Dear PyGui_ users.

## Installation

Ensure you have at least Python 3.6 64bit and _dearpygui_.
 ```
 pip install dearpygui_ext
 or
 pip3 install dearpygui_ext
 ```
 
## Resources
 
 [![Chat on Discord](https://img.shields.io/discord/736279277242417272?logo=discord)](https://discord.gg/tyE7Gu4)
[![Reddit](https://img.shields.io/reddit/subreddit-subscribers/dearpygui?label=r%2Fdearpygui)](https://www.reddit.com/r/DearPyGui/)
 
- [Documentation](https://github.com/hoffstadt/DearPyGui/wiki) comprehensive documentaion, tutorials, and examples.
- [Feature Tracker](https://github.com/hoffstadt/DearPyGui/projects/5) all proposed new features.
- [Bug Tracker](https://github.com/hoffstadt/DearPyGui/projects/1) current bugs and issues.

## Support

If you are having issues or want to help, here are some places you can go:
- [Github Discussions](https://github.com/hoffstadt/DearPyGui_Ext/discussions/)
- [Discord Forum](https://discord.gg/tyE7Gu4)
- [Reddit](https://www.reddit.com/r/DearPyGui/)

## Sponsors

![GitHub Sponsors](https://img.shields.io/github/sponsors/hoffstadt?label=Github%20Sponsors)
![Open Collective](https://img.shields.io/opencollective/sponsors/dearpygui?label=Open%20Collective%20Sponsors)

 If you enjoy _Dear PyGui_ and _Dear PyGui Extensions_ please consider becoming a [sponsor](https://github.com/hoffstadt/DearPyGui/wiki/Sponsors).

Ongoing _Dear PyGui_ development is financially supported by users and private sponsors.

These include:
* 🏢 [Anthony Tanbakuchi](https://github.com/kuchi) _Corporate Sponsor_
* 🏆 [Dean Keinan](https://github.com/deankeinan) _Partner Sponsor_
* 🏆 [何凌锋](https://github.com/Hedaozi) _Partner Sponsor_
* 🏆 [Anthony Doupe](https://github.com/Atlamillias) _Partner Sponsor_
* 🏆 [Ray Heasman](https://github.com/rheasman) _Partner Sponsor_
* 🏆 [Marco Studer](https://github.com/Mstpyt) _Partner Sponsor_
* 🏆 [Scripts](https://github.com/scriptslol) _Partner Sponsor_
* 🥇 [Caden Bloxham](https://github.com/cbxm) _Gold Sponsor_
* 🥇 [Yan Zaretskiy](https://github.com/mindv0rtex) _Gold Sponsor_
* 🥇 [Leron Gray](https://github.com/daddycocoaman) _Gold Sponsor_
* 🥇 [Trinnik](https://github.com/Trinnik) _Gold Sponsor_
* 🥇 [Barney Mannerings](https://github.com/barnabee) _Gold Sponsor_
* 🥇 [RB Blackstone](https://github.com/RBBlackstone) _Gold Sponsor_
* 🥇 [Charles Ray](https://github.com/ray-5050) _Gold Sponsor_


Thank you to all other [sponsors](https://github.com/hoffstadt/DearPyGui/wiki/Sponsors) for keeping this project moving forward!

<a href="https://www.buymeacoffee.com/DearPyGui"><img src="https://img.buymeacoffee.com/button-api/?text=Buy us a coffee&emoji=&slug=DearPyGui&button_colour=FFDD00&font_colour=000000&font_family=Cookie&outline_colour=000000&coffee_colour=ffffff"></a>

## Credits

Developed by [Jonathan Hoffstadt](https://github.com/hoffstadt), [Preston Cothren](https://github.com/Pcothren), and every direct or indirect contributor.

[Omar Cornut](http://www.miracleworld.net/) for all his incredible work on [Dear ImGui](https://github.com/ocornut/imgui).

[Evan Pezent](http://evanpezent.com/) for all his work on [ImPlot](https://github.com/epezent/implot).

[Johann Muszynski](https://github.com/Nelarius) for all of his work on [imnodes](https://github.com/Nelarius/imnodes).

## License

_Dear PyGui_ and _Dear PyGui Extensions_ are licensed under the [MIT License](https://github.com/hoffstadt/DearPyGui_Ext/blob/master/LICENSE).

==> dearpygui_ext-0.9.5.tar.gz: dearpygui_ext-0.9.5/README.md <==
<a id="user-content-dear-pygui" class="anchor" aria-hidden="true" href="#dear-pygui">
 
<div align="center">
  <img src="https://github.com/hoffstadt/DearPyGui/blob/assets/newlogo.jpg?raw=true" alt="Dear PyGui">
</div>

</a>

<h6 align="center">(This library is available under a free and permissive license however, if you Enjoy <i>Dear PyGui</i> please consider becoming a <a href="https://github.com/hoffstadt/DearPyGui/wiki/Sponsors">Sponsor</a>)</h6>

![Python Version](https://img.shields.io/pypi/pyversions/dearpygui-ext)
[![PYPI](https://img.shields.io/pypi/v/dearpygui-ext)](https://pypi.org/project/dearpygui-ext/)
[![Build](https://github.com/hoffstadt/DearPyGui_Ext/actions/workflows/BuildPackage.yml/badge.svg)](https://github.com/hoffstadt/DearPyGui_Ext/actions/workflows/BuildPackage.yml)
[![Documentation Status](https://readthedocs.org/projects/dearpygui-ext/badge/?version=latest)](https://dearpygui-ext.readthedocs.io/en/latest/?badge=latest)

**Dear PyGui Extensions** is a collection of useful tools, abstractions, and simplification layers built with/for _Dear PyGui_ users.

## Installation

Ensure you have at least Python 3.6 64bit and _dearpygui_.
 ```
 pip install dearpygui_ext
 or
 pip3 install dearpygui_ext
 ```
 
## Resources
 
 [![Chat on Discord](https://img.shields.io/discord/736279277242417272?logo=discord)](https://discord.gg/tyE7Gu4)
[![Reddit](https://img.shields.io/reddit/subreddit-subscribers/dearpygui?label=r%2Fdearpygui)](https://www.reddit.com/r/DearPyGui/)
 
- [Documentation](https://github.com/hoffstadt/DearPyGui/wiki) comprehensive documentaion, tutorials, and examples.
- [Feature Tracker](https://github.com/hoffstadt/DearPyGui/projects/5) all proposed new features.
- [Bug Tracker](https://github.com/hoffstadt/DearPyGui/projects/1) current bugs and issues.

## Support

If you are having issues or want to help, here are some places you can go:
- [Github Discussions](https://github.com/hoffstadt/DearPyGui_Ext/discussions/)
- [Discord Forum](https://discord.gg/tyE7Gu4)
- [Reddit](https://www.reddit.com/r/DearPyGui/)

## Sponsors

![GitHub Sponsors](https://img.shields.io/github/sponsors/hoffstadt?label=Github%20Sponsors)
![Open Collective](https://img.shields.io/opencollective/sponsors/dearpygui?label=Open%20Collective%20Sponsors)

 If you enjoy _Dear PyGui_ and _Dear PyGui Extensions_ please consider becoming a [sponsor](https://github.com/hoffstadt/DearPyGui/wiki/Sponsors).

Ongoing _Dear PyGui_ development is financially supported by users and private sponsors.

These include:
* 🏢 [Anthony Tanbakuchi](https://github.com/kuchi) _Corporate Sponsor_
* 🏆 [Dean Keinan](https://github.com/deankeinan) _Partner Sponsor_
* 🏆 [何凌锋](https://github.com/Hedaozi) _Partner Sponsor_
* 🏆 [Anthony Doupe](https://github.com/Atlamillias) _Partner Sponsor_
* 🏆 [Ray Heasman](https://github.com/rheasman) _Partner Sponsor_
* 🏆 [Marco Studer](https://github.com/Mstpyt) _Partner Sponsor_
* 🏆 [Scripts](https://github.com/scriptslol) _Partner Sponsor_
* 🥇 [Caden Bloxham](https://github.com/cbxm) _Gold Sponsor_
* 🥇 [Yan Zaretskiy](https://github.com/mindv0rtex) _Gold Sponsor_
* 🥇 [Leron Gray](https://github.com/daddycocoaman) _Gold Sponsor_
* 🥇 [Trinnik](https://github.com/Trinnik) _Gold Sponsor_
* 🥇 [Barney Mannerings](https://github.com/barnabee) _Gold Sponsor_
* 🥇 [RB Blackstone](https://github.com/RBBlackstone) _Gold Sponsor_
* 🥇 [Charles Ray](https://github.com/ray-5050) _Gold Sponsor_


Thank you to all other [sponsors](https://github.com/hoffstadt/DearPyGui/wiki/Sponsors) for keeping this project moving forward!

<a href="https://www.buymeacoffee.com/DearPyGui"><img src="https://img.buymeacoffee.com/button-api/?text=Buy us a coffee&emoji=&slug=DearPyGui&button_colour=FFDD00&font_colour=000000&font_family=Cookie&outline_colour=000000&coffee_colour=ffffff"></a>

## Credits

Developed by [Jonathan Hoffstadt](https://github.com/hoffstadt), [Preston Cothren](https://github.com/Pcothren), and every direct or indirect contributor.

[Omar Cornut](http://www.miracleworld.net/) for all his incredible work on [Dear ImGui](https://github.com/ocornut/imgui).

[Evan Pezent](http://evanpezent.com/) for all his work on [ImPlot](https://github.com/epezent/implot).

[Johann Muszynski](https://github.com/Nelarius) for all of his work on [imnodes](https://github.com/Nelarius/imnodes).

## License

_Dear PyGui_ and _Dear PyGui Extensions_ are licensed under the [MIT License](https://github.com/hoffstadt/DearPyGui_Ext/blob/master/LICENSE).
